@@ -288,7 +288,7 @@
     abbrev-mode
     local-abbrev-table
     ;; And finally the syntax table and local map.
-    ((syntax-table . set-syntax-table))
+    ((syntax-table . set-syntax-table) buffer)
     ((current-local-map . use-local-map) buffer)
     paragraph-separate
     paragraph-start
@@ -997,6 +997,7 @@ PRIVATE, if supplied and non-nil, means that this class is a private
 or internal class, usually one invoked by another class via :classes,
 and is not for the user to see.")
 
+;;;###autoload
 (defun mmm-add-classes (classes)
   "Add the submode classes CLASSES to `mmm-classes-alist'."
   (dolist (class classes)
@@ -1026,7 +1027,7 @@ The CLASSES are all made private, i.e. non-user-visible."
 ;;}}}
 ;;{{{ Version Number
 
-(defconst mmm-version "0.5.1"
+(defconst mmm-version "0.5.2"
   "Current version of MMM Mode.")
 
 (defun mmm-version ()
